@@ -5,20 +5,27 @@ class ReportsController < InheritedResources::Base
   before_filter :raise_if_enable_read_only_mode, :only => [:new, :edit, :update, :destroy]
   before_filter :handle_raw_post, :only => [:create, :upload]
 
-  attr_accessor :errors
-
   def index
-    index! do |success,failure|
-      success.html do
+    index! do |format|
+      format.html do
         if params[:kind] == "inspect"
           @reports = paginate_scope Report.inspections
         else
+          @controller_action = 'all'
           @reports = paginate_scope Report.applies
         end
       end
     end
   end
 
+  [:failed, :changed, :unchanged, :pending].each do |action|
+    define_method(action) {
+      @reports = paginate_scope Report.send(action)
+      @controller_action = action.to_s
+      render :index
+    }
+  end
+
   def create
     if SETTINGS.disable_legacy_report_upload_url
       render :text => "Access Denied, this url has been disabled, try /reports/upload", :status => 403
